@@ -7,7 +7,7 @@ from patchwork.common.client.scm import (
     GithubClient,
     GitlabClient,
     ScmPlatformClientProtocol,
-    get_slug_from_remote_url,
+    get_slug_from_remote_url, AzureDevopsClient,
 )
 from patchwork.logger import logger
 from patchwork.step import Step, StepStatus
@@ -30,10 +30,12 @@ class CreatePR(Step):
                 self.scm_client = GithubClient(inputs["github_api_key"])
             elif "gitlab_api_key" in inputs.keys():
                 self.scm_client = GitlabClient(inputs["gitlab_api_key"])
+            elif "azuredevops_api_key" in inputs.keys():
+                self.scm_client = AzureDevopsClient(inputs["azuredevops_api_key"])
             else:
                 logger.warning(
-                    f'Missing required input data: "github_api_key" or "gitlab_api_key",'
-                    f" PR creation will be disabled."
+                    f'Missing required input data: "github_api_key", "gitlab_api_key" or "azuredevops_api_key". '
+                    f"PR creation will be disabled."
                 )
                 self.enabled = False
 
@@ -121,7 +123,6 @@ def push(repo: git.Repo, args) -> bool:
         logger.error("Git command failed with:")
         logger.error(e.stdout)
         logger.error(e.stderr)
-        pass
 
     freeze_func = getattr(logger, "freeze", None)
     if freeze_func is None:
@@ -135,7 +136,6 @@ def push(repo: git.Repo, args) -> bool:
         logger.error("Git command failed with:")
         logger.error(e.stdout)
         logger.error(e.stderr)
-        pass
 
     return False
 
